📚 API Reference
=================

Rich-powered handler
--------------------

.. automodule:: chameleon_log.rich
   :members:
   :undoc-members:
   :show-inheritance:

Journald integration
--------------------

.. automodule:: chameleon_log.journald
   :members:
   :undoc-members:
   :show-inheritance:

Detector
--------

.. automodule:: chameleon_log.detectors
   :members:
   :undoc-members:
   :show-inheritance:
